@@ -15,7 +15,7 @@ class HotelingApi(PersonSettingsApiChild):
 
     feature = 'hoteling'
 
-    def read(self, *, person_id: str, org_id: str = None) -> bool:
+    def read(self, person_id: str, org_id: str = None) -> bool:
         """
         Read Hoteling Settings for a Person
 
@@ -39,7 +39,7 @@ class HotelingApi(PersonSettingsApiChild):
         data = self.get(ep, params=params)
         return data['enabled']
 
-    def configure(self, *, person_id: str, enabled: bool, org_id: str = None):
+    def configure(self, person_id: str, enabled: bool, org_id: str = None):
         """
         Configure Hoteling Settings for a Person
 
