@@ -8,13 +8,13 @@ API is used in:
 """
 import json
 from dataclasses import dataclass
-from enum import Enum
 from typing import Optional, Union
 
 from pydantic import validator, parse_obj_as, root_validator
 
 from .common import PersonSettingsApiChild
 from ..base import ApiModel
+from ..base import SafeEnum as Enum
 from ..common import AuthCode
 from ..rest import RestSession
 
@@ -197,6 +197,7 @@ class OutgoingPermissions(ApiModel):
             r[call_type.lower()] = entry
         return r
 
+    # noinspection PyMethodOverriding
     def json(self, drop_call_types: set[str] = None) -> str:
         """
         :meta private:
@@ -207,15 +208,16 @@ class OutgoingPermissions(ApiModel):
             # default call types to be excluded from updates
             drop_call_types = {'url_dialing', 'unknown', 'casual'}
         data = self.dict(exclude={'calling_permissions'}, by_alias=True)
-        permissions = []
-        for call_type, call_type_permission in self.calling_permissions.__dict__.items():
-            call_type_permission: CallTypePermission
-            if not call_type_permission or (call_type in drop_call_types):
-                continue
-            ct_dict = call_type_permission.dict(by_alias=True)
-            ct_dict['callType'] = call_type.upper()
-            permissions.append(ct_dict)
-        data['callingPermissions'] = permissions
+        if self.calling_permissions is not None:
+            permissions = []
+            for call_type, call_type_permission in self.calling_permissions.__dict__.items():
+                call_type_permission: CallTypePermission
+                if not call_type_permission or (call_type in drop_call_types):
+                    continue
+                ct_dict = call_type_permission.dict(by_alias=True)
+                ct_dict['callType'] = call_type.upper()
+                permissions.append(ct_dict)
+            data['callingPermissions'] = permissions
         return json.dumps(data)
 
 
