@@ -81,6 +81,11 @@ class Calendar(WorkspaceEmail):
     calendar_type: Optional[CalendarType] = Field(alias='type')
 
 
+class WorkspaceSupportedDevices(str, Enum):
+    collaboration_devices = 'collaborationDevices'
+    phones = 'phones'
+
+
 class Workspace(ApiModel):
     """
     Workspace details
@@ -111,7 +116,10 @@ class Workspace(ApiModel):
     calendar: Optional[Calendar]
     #: Notes associated to the workspace.
     notes: Optional[str]
+    #: Hot desking status of the workspace.
     hotdesking_status: Optional[bool]
+    #: The supported devices for the workspace.
+    supported_devices: Optional[WorkspaceSupportedDevices]
 
     @validator('calling', pre=True)
     def validate_calling(cls, value):
@@ -219,9 +227,15 @@ class WorkspacesApi(ApiChild, base='workspaces'):
         :type org_id: str
         :return: generator of :class:`Workspace` instances
         """
-        params.update((to_camel(k), v)
-                      for i, (k, v) in enumerate(locals().items())
-                      if i and k != 'params' and v is not None)
+        def enum_str(p: Enum) -> str:
+            try:
+                return p.value
+            except:
+                pass
+            return p
+        params.update((to_camel(k), enum_str(v))
+                      for k, v in locals().items()
+                      if k not in {'self', 'params', 'enum_str'} and v is not None)
         if workspace_type is not None:
             params.pop('workspaceType')
             params['type'] = workspace_type
